package com.mdd.admin.controller.system;

import com.alibaba.fastjson2.JSONArray;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.aop.Log;
import com.mdd.admin.service.ISystemAuthMenuService;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.system.SystemMenuCreateValidate;
import com.mdd.admin.validate.system.SystemMenuUpdateValidate;
import com.mdd.admin.vo.system.SystemAuthMenuVo;
import com.mdd.common.aop.NotPower;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/system/menu"})
@Api(
   tags = {"系统菜单管理"}
)
public class SystemAuthMenuController {
   @Resource
   ISystemAuthMenuService iSystemAuthMenuService;

   @NotPower
   @GetMapping({"/route"})
   @ApiOperation("获取菜单路由")
   public AjaxResult<JSONArray> route() {
      List<Integer> roleIds = LikeAdminThreadLocal.getRoleIds();
      JSONArray lists = this.iSystemAuthMenuService.selectMenuByRoleId(roleIds);
      return AjaxResult.success(lists);
   }

   @NotPower
   @GetMapping({"/list"})
   @ApiOperation("获取菜单列表")
   public AjaxResult<JSONArray> list() {
      JSONArray lists = this.iSystemAuthMenuService.list();
      return AjaxResult.success(lists);
   }

   @GetMapping({"/detail"})
   @ApiOperation("获取菜单详情")
   public AjaxResult<SystemAuthMenuVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      SystemAuthMenuVo vo = this.iSystemAuthMenuService.detail(id);
      return AjaxResult.success(vo);
   }

   @Log(
      title = "菜单新增"
   )
   @PostMapping({"/add"})
   @ApiOperation("新增菜单")
   public AjaxResult<Object> add(@Validated @RequestBody SystemMenuCreateValidate createValidate) {
      this.iSystemAuthMenuService.add(createValidate);
      return AjaxResult.success();
   }

   @Log(
      title = "菜单编辑"
   )
   @PostMapping({"/edit"})
   @ApiOperation("菜单编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody SystemMenuUpdateValidate updateValidate) {
      this.iSystemAuthMenuService.edit(updateValidate);
      return AjaxResult.success();
   }

   @Log(
      title = "菜单删除"
   )
   @PostMapping({"/del"})
   @ApiOperation("菜单删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iSystemAuthMenuService.del(idValidate.getId());
      return AjaxResult.success();
   }
}
